@@ -95,8 +95,8 @@ def getConfigFile() -> str:
         try:
             jObject = {}
             jObject['tokenFilePath'] = '<Enter the fully qualified path to your token file here>'
-            jObject['selectedAnalyticsAPIEndpoint'] = 'https://phastwebservices-preview.dnv.com/api/analytics/v1/'
-            jObject['selectedClientAliasId'] = 'c02aee6b-4ab8-4fd8-9524-8bcd14617f1e'
+            jObject['selectedAnalyticsAPIEndpoint'] = 'https://phastwebservices.dnv.com/api/analytics/v1/'
+            jObject['selectedClientAliasId'] = PWS_CLIENT_ID
 
             with open(path,'w') as jsonFile:
                 json.dump(jObject, jsonFile)
